@@ -18,12 +18,30 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from typing import Tuple
+import builtins
+from typing import Final
 
-from .version import get_version
+from ._environ import Environ, environ  # noqa: F401
+from ._version import get_version, VersionType
 
-VERSION: Tuple[int, int, int, str, int] = (0, 1, 1, "final", 0)
+bool = environ.bool
+bytes = environ.bytes
+decimal = environ.decimal
+dict = environ.dict
+float = environ.float
+int = environ.int
+json = environ.json
+list = environ.list
+tuple = environ.tuple
+str = environ.str
+load = environ.load
+get = environ.get
+set = environ.set
+setdefault = environ.setdefault
 
-__author__: str = "Raffaele Salmaso"
-__author_email__: str = "raffaele.salmaso@gmail.com"
-__version__: str = get_version(VERSION)
+
+VERSION: Final[VersionType] = (0, 5, 0, "final", 0)
+
+__author__: Final[builtins.str] = "Raffaele Salmaso"
+__author_email__: Final[builtins.str] = "raffaele.salmaso@gmail.com"
+__version__: Final[builtins.str] = get_version(VERSION)
